
import { useState } from 'react';
import { Task } from '@/utils/mockData';
import { Button } from '@/components/ui/button';
import { FileDown, Check } from 'lucide-react';
import { toast } from 'sonner';

interface ExportOptionsProps {
  tasks: Task[];
}

const ExportOptions = ({ tasks }: ExportOptionsProps) => {
  const [isExporting, setIsExporting] = useState(false);

  const exportToCSV = () => {
    try {
      setIsExporting(true);
      
      // Create CSV content
      const headers = ['Description', 'Department', 'Deadline', 'Priority', 'Status', 'Context'];
      const csvContent = [
        headers.join(','),
        ...tasks.map(task => [
          `"${task.description.replace(/"/g, '""')}"`,
          `"${task.department.replace(/"/g, '""')}"`,
          task.deadline,
          task.priority,
          task.status,
          `"${task.context.replace(/"/g, '""')}"`
        ].join(','))
      ].join('\n');
      
      // Create a Blob and download
      const blob = new Blob([csvContent], { type: 'text/csv;charset=utf-8;' });
      const url = URL.createObjectURL(blob);
      const link = document.createElement('a');
      link.setAttribute('href', url);
      link.setAttribute('download', `secupolicy_tasks_${new Date().toISOString().split('T')[0]}.csv`);
      document.body.appendChild(link);
      link.click();
      document.body.removeChild(link);
      
      toast.success('CSV file exported successfully');
    } catch (error) {
      console.error('Export error:', error);
      toast.error('Failed to export CSV file');
    } finally {
      setIsExporting(false);
    }
  };

  return (
    <div className="w-full max-w-xs mx-auto">
      <Button
        onClick={exportToCSV}
        disabled={isExporting || tasks.length === 0}
        className="w-full rounded-full"
        variant="outline"
      >
        {isExporting ? (
          <>
            <Check className="w-4 h-4 mr-2 animate-pulse" />
            Exporting...
          </>
        ) : (
          <>
            <FileDown className="w-4 h-4 mr-2" />
            Export to CSV
          </>
        )}
      </Button>
    </div>
  );
};

export default ExportOptions;
